
****************
itteration_tools
****************


SimpleSingleParamOptimiser
==========================

.. autoclass:: sonnetsuiteshelper.itteration_tools.SimpleSingleParamOptimiser()
   :members:
